@@ -6,6 +6,7 @@ import com.facebook.react.bridge.ReactMethod;
 import com.facebook.react.bridge.ReadableMap;
 import com.facebook.react.bridge.ReadableArray;
 import com.facebook.react.bridge.ReadableMapKeySetIterator;
+import com.facebook.react.bridge.Promise;
 
 import com.google.android.gms.analytics.GoogleAnalytics;
 import com.google.android.gms.analytics.HitBuilders;
@@ -481,4 +482,15 @@ public class GoogleAnalyticsBridge extends ReactContextBaseJavaModule {
         tracker.setScreenName(screenName);
         tracker.send(new HitBuilders.ScreenViewBuilder().setNewSession().build());
     }
+
+    @ReactMethod
+    public void dispatch(Promise promise) {
+        GoogleAnalytics analytics = getAnalyticsInstance();
+        try {
+            analytics.dispatchLocalHits();
+            promise.resolve(true);
+        } catch (Exception ex) {
+            promise.reject(ex);
+        }
+    }
 }
